@@ -117,6 +117,10 @@ class Telegram:
             raise ValueError('You must provide bot_token or phone')
 
         self._database_encryption_key = database_encryption_key
+        if isinstance(self._database_encryption_key, str):
+            self._database_encryption_key = self._database_encryption_key.encode()
+
+        self._database_encryption_key = base64.b64encode(self._database_encryption_key).decode()
 
         if not files_directory:
             hasher = hashlib.md5()
@@ -723,22 +727,26 @@ class Telegram:
             self.files_directory,
             self.use_test_dc,
         )
-        data = {
-            # todo: params
+
+        parameters = {
+            'use_test_dc': self.use_test_dc,
+            'api_id': self.api_id,
+            'api_hash': self.api_hash,
+            'device_model': self.device_model,
+            'system_version': self.system_version,
+            'application_version': self.application_version,
+            'system_language_code': self.system_language_code,
+            'database_directory': os.path.join(self.files_directory, 'database'),
+            'use_message_database': self.use_message_database,
+            'files_directory': os.path.join(self.files_directory, 'files'),
+            'use_secret_chats': self.use_secret_chats,
+        }
+        data: Dict[str, typing.Any] = {
             '@type': 'setTdlibParameters',
-            'parameters': {
-                'use_test_dc': self.use_test_dc,
-                'api_id': self.api_id,
-                'api_hash': self.api_hash,
-                'device_model': self.device_model,
-                'system_version': self.system_version,
-                'application_version': self.application_version,
-                'system_language_code': self.system_language_code,
-                'database_directory': os.path.join(self.files_directory, 'database'),
-                'use_message_database': self.use_message_database,
-                'files_directory': os.path.join(self.files_directory, 'files'),
-                'use_secret_chats': self.use_secret_chats,
-            },
+            'parameters': parameters,
+            # since tdlib 1.8.6
+            'database_encryption_key': self._database_encryption_key,
+            **parameters,
         }
 
         return self._send_data(data, result_id='updateAuthorizationState')
@@ -746,14 +754,9 @@ class Telegram:
     def _send_encryption_key(self) -> AsyncResult:
         logger.info('Sending encryption key')
 
-        key = self._database_encryption_key
-
-        if isinstance(key, str):
-            key = key.encode()
-
         data = {
             '@type': 'checkDatabaseEncryptionKey',
-            'encryption_key': base64.b64encode(key).decode(),
+            'encryption_key': self._database_encryption_key,
         }
 
         return self._send_data(data, result_id='updateAuthorizationState')
